;; Generated package description from tomelr.el  -*- no-byte-compile: t -*-
(define-package "tomelr" "0.2.5" "Convert S-expressions to TOML" '((emacs "26.3")) :commit "8fc2257ec072a3fc3316c7f311722db50b37558e" :authors '(("Kaushal Modi" . "kaushal.modi@gmail.com")) :maintainer '("Kaushal Modi" . "kaushal.modi@gmail.com") :keywords '("data" "tools" "toml" "serialization" "config") :url "https://github.com/kaushalmodi/tomelr/")
